@@ -16,11 +16,11 @@ def get_logger(log_file: str = "logs.log") -> logging.Logger:
     Args:
         log_file: relative file name for the log file to be stored in src/utils/../../logs/.
     """
-    root_dir = get_root_dir()
+    root_dir = os.getcwd()
     log_dir = os.path.join(root_dir, "logs")
     if "logs" not in os.listdir(root_dir):
         os.mkdir(log_dir)
-    if log_file == "logs.log":
+    if log_file == "logs.log" and log_file in os.listdir(log_dir):
         os.remove(os.path.join(log_dir, log_file))
     if log_file in os.listdir(log_dir):
         raise ValueError(f"the provided log file already exists : {log_file}")
